
Sardana API
===========

.. rubric:: APIs

.. toctree::
    :maxdepth: 1

    Macro API <macro>
    Controller API <controller>
    Pool Tango API <tango_device_pool>
    MacroServer Tango API <tango_macroserver>
    Library <sardana/sardana>
    
